# This script finishes the installation of TMDA.
# Written by Joseph C. Lininger, <jbahm@pcdesk.net>
#
# Copyright (C) 2004 Joseph C. Lininger
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  
# USA
#
# A complete copy of the license can be found in the file
# /usr/doc/tmda-1.0.3/COPYING

# this function is used to install a configuration file
# The only parameter is the name of the file to install
installConfig() {
  # if the file already exists, don't overwrite it with the new one
  if [ -r $1 ]; then
    # throw out the extra file if the old and new are the same
    if [ "`cat $1 | md5sum`" = "`cat $1.new | md5sum`" ]; then
      rm -f "$1.new"
    fi
  # move the old file in to place
  else
    mv "$1.new" "$1"
  fi
}

# this function adds a user account to the system
# The parameters should be passed in as follows:
# username, group, home directory, shell, gecos
addUser() {
  # add the user account if it doesn't already exist
if [ ! `cut -d ':' -f 1 etc/passwd | egrep -i "^$1$"` ]; then
    useradd -g "$2" -d "$3" -s "$4" -c "$5" "$1"
  fi
}

# this function adds a group account to the system
# The only parameter is the name of the group to ad
addGroup() {
  # add the group if it doesn't already exist
  if [ ! `cut -d ':' -f 1 etc/group | egrep -i "^$1$"` ]; then
    groupadd "$1"
  fi
}

# execution of the script begins here
# move the tmdarc and rc.tofmipd file into place
installConfig "etc/tmdarc"
installConfig "etc/rc.d/rc.tofmipd"
# create the tofmipd user and group
addGroup "tofmipd"
addUser "tofmipd" "tofmipd" "/dev/null" "/bin/false" "system account for tmda-ofmipd"
# print advisory message about tmdarc file
echo "Please note, you will need to edit the TMDA configuration file to"
echo "customize it for your system."
echo "Please see the file /usr/doc/tmda-1.0.3/readme.slackware for more"
echo "information."
